<?php
/**
 * Define customizer custom classes
 *
 * @package CodeVibrant
 * @subpackage Yaatra Mag
 * @since 1.0.0
 */

if ( class_exists( 'WP_Customize_Control' ) ) {

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Radio toggle customize control.
     *
     * @since  1.0.0
     * @access public
     */
    class Yaatra_Mag_Toggle_Checkbox_Custom_Control extends WP_Customize_Control {

		/**
		 * The type of control being rendered
		 */
		public $type = 'cv-toogle_checkbox';
		
		/**
		 * Render the control in the customizer
		 */
		public function render_content() {
		?>
			<div class="cv-toggle-checkbox-wrap">
				<input id="<?php echo esc_attr( $this->id ); ?>" class="cv-checkbox-toggle" type="checkbox" <?php $this->link(); checked( true, $this->value() ); ?> data-toggle="toggle" data-style="slow" >
				<label for="<?php echo esc_attr( $this->id ); ?>"><?php echo esc_html( $this->label ); ?></label>
				<span id="_customize-description-<?php echo esc_attr( $this->id ); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
			</span>
		<?php
		}
	}

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Radio image customize control.
     *
     * @since  1.0.0
     * @access public
     */
    class Yaatra_Mag_Customize_Control_Radio_Image extends WP_Customize_Control {
        /**
         * The type of customize control being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'cv-radio-image';

        /**
         * Loads the jQuery UI Button script and custom scripts/styles.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function enqueue() {
            wp_enqueue_script( 'jquery-ui-button' );
        }

        /**
         * Add custom JSON parameters to use in the JS template.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function to_json() {
            parent::to_json();

            // We need to make sure we have the correct image URL.
            foreach ( $this->choices as $value => $args )
                $this->choices[ $value ]['url'] = esc_url( sprintf( $args['url'], get_template_directory_uri(), get_stylesheet_directory_uri() ) );

            $this->json['choices'] = $this->choices;
            $this->json['link']    = $this->get_link();
            $this->json['value']   = $this->value();
            $this->json['id']      = $this->id;
        }


        /**
         * Underscore JS template to handle the control's output.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */

        public function content_template() { ?>
            <# if ( data.label ) { #>
                <span class="customize-control-title">{{ data.label }}</span>
            <# } #>

            <# if ( data.description ) { #>
                <span class="description customize-control-description">{{{ data.description }}}</span>
            <# } #>

            <div class="buttonset">

                <# for ( key in data.choices ) { #>

                    <input type="radio" value="{{ key }}" name="_customize-{{ data.type }}-{{ data.id }}" id="{{ data.id }}-{{ key }}" {{{ data.link }}} <# if ( key === data.value ) { #> checked="checked" <# } #> /> 

                    <label for="{{ data.id }}-{{ key }}">
                        <span class="screen-reader-text">{{ data.choices[ key ]['label'] }}</span>
                        <img src="{{ data.choices[ key ]['url'] }}" title="{{ data.choices[ key ]['label'] }}" alt="{{ data.choices[ key ]['label'] }}" />
                    </label>
                <# } #>

            </div><!-- .buttonset -->
        <?php }
    }

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Customize controls for repeater field
     *
     * @since 1.0.0
     */
    class Yaatra_Mag_Repeater_Controler extends WP_Customize_Control {
        /**
         * The control type.
         *
         * @access public
         * @var string
         */
        public $type = 'cv-repeater';

        public $yaatra_mag_box_label = '';

        public $yaatra_mag_box_add_control = '';

        /**
         * The fields that each container row will contain.
         *
         * @access public
         * @var array
         */
        public $fields = array();

        /**
         * Repeater drag and drop controller
         *
         * @since  1.0.0
         */
        public function __construct( $manager, $id, $args = array(), $fields = array() ) {
            $this->fields = $fields;
            $this->yaatra_mag_box_label = $args['yaatra_mag_box_label'] ;
            $this->yaatra_mag_box_add_control = $args['yaatra_mag_box_add_control'];
            parent::__construct( $manager, $id, $args );
        }

        public function render_content() {

            $values = json_decode( $this->value() );
            $repeater_id = $this->id;
            $field_count = count( $values );
        ?>
            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>

            <?php if ( $this->description ) { ?>
                <span class="description customize-control-description">
                    <?php echo wp_kses_post( $this->description ); ?>
                </span>
            <?php } ?>

            <ul class="cv-repeater-field-control-wrap">
                <?php $this->yaatra_mag_get_fields(); ?>
            </ul>

            <input type="hidden" <?php $this->link(); ?> class="cv-repeater-collector" value="<?php echo esc_attr( $this->value() ); ?>" />
            <input type="hidden" name="<?php echo esc_attr( $repeater_id ).'_count'; ?>" class="field-count" value="<?php echo absint( $field_count ); ?>">
            <input type="hidden" name="field_limit" class="field-limit" value="6">
            <button type="button" class="button cv-repeater-add-control-field"><?php echo esc_html( $this->yaatra_mag_box_add_control ); ?></button>
    <?php
        }

        private function yaatra_mag_get_fields() {
            $fields = $this->fields;
            $values = json_decode( $this->value() );

            if ( is_array( $values ) ) {
            	foreach( $values as $value ) {
        ?>
	            <li class="cv-repeater-field-control">
	            <h3 class="cv-repeater-field-title"><?php echo esc_html( $this->yaatra_mag_box_label ); ?></h3>
	            
	            <div class="cv-repeater-fields">
	            <?php
	                foreach ( $fields as $key => $field ) {
	                $class = isset( $field['class'] ) ? $field['class'] : '';
	            ?>
	                <div class="cv-repeater-field cv-repeater-type-<?php echo esc_attr( $field['type'] ).' '.esc_attr( $class ); ?>">

	                <?php 
	                    $label = isset( $field['label'] ) ? $field['label'] : '';
	                    $description = isset( $field['description'] ) ? $field['description'] : '';
	                    if ( $field['type'] != 'checkbox' ) { 
	                ?>
	                        <span class="customize-control-title"><?php echo esc_html( $label ); ?></span>
	                        <span class="description customize-control-description"><?php echo esc_html( $description ); ?></span>
	                <?php 
	                    }

	                    $new_value = isset( $value->$key ) ? $value->$key : '';
	                    $default = isset( $field['default'] ) ? $field['default'] : '';

	                    switch ( $field['type'] ) {
	                        /**
                             * Text field
                             */
                            case 'text':
	                            echo '<input data-default="'.esc_attr( $default ).'" data-name="'.esc_attr( $key ).'" type="text" value="'.esc_attr( $new_value ).'"/>';
	                            break;

	                        /**
                             * URL field
                             */
                            case 'url':
	                            echo '<input data-default="'.esc_attr( $default ).'" data-name="'.esc_attr( $key ).'" type="text" value="'.esc_url( $new_value ).'"/>';
	                            break;

	                        /**
                             * Social Icon field
                             */
                            case 'social_icon':
                                $yaatra_mag_font_awesome_social_icon_array = yaatra_mag_font_awesome_social_icon_array();
	                            echo '<div class="cv-repeater-selected-icon"><i class="'.esc_attr( $new_value ).'"></i><span><i class="fa fa-angle-down"></i></span></div><ul class="cv-repeater-icon-list cv-clearfix">';
	                            foreach ( $yaatra_mag_font_awesome_social_icon_array as $yaatra_mag_font_awesome_icon ) {
	                                $icon_class = $new_value == $yaatra_mag_font_awesome_icon ? 'icon-active' : '';
	                                echo '<li class='.esc_attr( $icon_class ).'><i class="'.esc_attr( $yaatra_mag_font_awesome_icon ).'"></i></li>';
	                            }
	                            echo '</ul><input data-default="'.esc_attr( $default ).'" type="hidden" value="'.esc_attr( $new_value ).'" data-name="'.esc_attr( $key ).'"/>';
	                            break;

	                        default:
	                            break;
	                    }
	                ?>
	                </div>
            <?php
                }
            ?>
	                <div class="cv-clearfix cv-repeater-footer">
	                    <div class="alignright">
	                    <a class="cv-repeater-field-remove" href="#remove"><?php esc_html_e( 'Delete', 'yaatra-mag' ) ?></a> |
	                    <a class="cv-repeater-field-close" href="#close"><?php esc_html_e( 'Close', 'yaatra-mag' ) ?></a>
	                    </div>
	                </div><!-- .cv-repeater-footer -->
	            </div><!-- .cv-repeater-fields-->
	            </li>
        <?php   
            	}
            }
        }
    }

    /*-----------------------------------------------------------------------------------------------------------------------------*/
    /**
	 * Heading control
	 *
     * @since 1.0.0
	 */
	class Yaatra_Mag_Heading_Controler extends WP_Customize_Control {

		/**
		 * The control type.
		 *
		 * @access public
		 * @var string
		 */
		public $type = 'cv-heading';

		/**
		 * An Underscore (JS) template for this control's content (but not its container).
		 *
		 * Class variables for this control class are available in the `data` JS object;
		 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
		 *
		 * @see WP_Customize_Control::print_template()
		 *
		 * @access protected
		 */
		protected function content_template() {
	?>
			<h4 class="cv-customizer-heading">{{{ data.label }}}</h4>
			<div class="description">{{{ data.description }}}</div>
	<?php
		}
    }
    
    /*-----------------------------------------------------------------------------------------------------------------------------*/
    if ( ! class_exists( 'Yaatra_Mag_Control_Color' ) ) {

        /**
         * Alpha Color control
         *
         * @since 1.0.0
         */
        class Yaatra_Mag_Control_Color extends WP_Customize_Control {
    
            /**
             * The control type.
             *
             * @access public
             * @var string
             */
    
            public $type = 'cv-alpha-color';
    
            public $tooltip = '';
    
            /**
             * Add support for palettes to be passed in.
             *
             * Supported palette values are true, false, or an array of RGBa and Hex colors.
             *
             * @var bool
             */
            public $palette;
    
            /**
             * Add support for showing the opacity value on the slider handle.
             *
             * @var array
             */
            public $show_opacity;
    
            /**
             * Enqueue control related scripts/styles.
             *
             * @access public
             */
            public function enqueue() {
                wp_enqueue_style( 'yaatra-alpha-color-picker-style', get_template_directory_uri() . '/inc/customizer/assets/alpha-color/color-alpha-picker.min.css', array( 'wp-color-picker' ), '1.0.0' );

                wp_enqueue_script( 'yaatra-alpha-color-picker-script', get_template_directory_uri() . '/inc/customizer/assets//alpha-color/color-alpha-picker.min.js', array( 'jquery', 'wp-color-picker' ), false, true );
            }
    
            /**
             * Refresh the parameters passed to the JavaScript via JSON.
             *
             * @see WP_Customize_Control::to_json()
             */
            public function to_json() {
                parent::to_json();
    
                if ( isset( $this->default ) ) {
                    $this->json['default']  = $this->default;
                } else {
                    $this->json['default']  = $this->setting->default;
                }
    
                // Process the palette
                if ( is_array( $this->palette ) ) {
                    $this->json['palette'] = implode( '|', $this->palette );
                } else {
                    // Default to true.
                    $this->json['palette'] = ( false === $this->palette || 'false' === $this->palette ) ? 'false' : 'true';
                }
    
                $this->json['show_opacity'] = ( false === $this->show_opacity || 'false' === $this->show_opacity ) ? 'false' : 'true';
                $this->json['value']        = $this->value();
                $this->json['link']         = $this->get_link();
                $this->json['id']           = $this->id;
                $this->json['tooltip']      = $this->tooltip;
    
            }
    
            /**
             * An Underscore (JS) template for this control's content (but not its container).
             *
             * Class variables for this control class are available in the `data` JS object;
             * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
             *
             * @see WP_Customize_Control::print_template()
             *
             * @access protected
             */
            protected function content_template() {
        ?>
    
                <label>
                    <# if ( data.tooltip ) { #>
                        <a href="#" class="tooltip hint--left" data-hint="{{ data.tooltip }}"><span class='dashicons dashicons-info'></span></a>
                    <# } #>
    
                    <# if ( data.label ) { #>
                        <span class="customize-control-title">{{{ data.label }}}</span>
                    <# } #>
                    <# if ( data.description ) { #>
                        <span class="description customize-control-description">{{{ data.description }}}</span>
                    <# } #>
                    <div>
                        <input class="alpha-color-control" type="text"  value="{{ data.value }}" data-show-opacity="{{ data.show_opacity }}" data-palette="{{ data.palette }}" data-default-color="{{ data.default }}" {{{ data.link }}} />
                    </div>
                </label>
                
        <?php
            }
        }
    
    }
}