<?php
/**
 * Yaatra Mag Footer panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Yaatra Mag
 * @since 1.0.0
 */

add_action( 'customize_register', 'yaatra_mag_footer_settings_register' );

function yaatra_mag_footer_settings_register( $wp_customize ) {

    /**
     * Add Header Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'yaatra_mag_footer_settings_panel',
	    array(
	        'priority'       => 50,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Footer Settings', 'yaatra-mag' ),
	    )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Footer section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yaatra_mag_footer_section',
        array(
        	'priority'       => 35,
            'capability'     => 'edit_theme_options',
            'panel'          => 'yaatra_mag_footer_settings_panel',
        	'theme_supports' => '',
            'title'          => __( 'Footer Section', 'yaatra-mag' )
        )
    );


    /**
     * Image upload field for banner image
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_footer_logo_image',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control( new WP_Customize_Image_Control (
        $wp_customize,
        'yaatra_mag_footer_logo_image',
	        array(
	            'label'         => __( 'Footer Logo', 'yaatra-mag' ),
	            'section'       => 'yaatra_mag_footer_section',
	            'settings'      => 'yaatra_mag_footer_logo_image',
	            'type'          => 'upload',
	            'priority'      => 5
	        )
    	)
	);

	/**
     * Text field for copyright
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_copyright_text',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'yaatra_mag_copyright_text',
        array(
            'label'         => __( 'Copyright Text', 'yaatra-mag' ),
            'section'       => 'yaatra_mag_footer_section',
            'settings'      => 'yaatra_mag_copyright_text',
            'type'          => 'text',
            'priority'      => 10
        )
    );

    /*--------------------------------------------------------------------------------------------------------------------*/
	/**
     * Footer Style section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yaatra_mag_footer_style_section',
        array(
        	'priority'       => 5,
        	'panel'          => 'yaatra_mag_footer_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Style', 'yaatra-mag' )
        )
    );
    
    /**
     * Heading field for Footer Style
     *
     * Footer Settings > Style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 'yaatra_mag_footer_background_heading',
        array(
            'capability'        => 'edit_theme_options',
            'theme_options'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control( new Yaatra_Mag_Heading_Controler(
        $wp_customize, 'yaatra_mag_footer_background_heading',
            array(
                'priority'      => 10,
                'section'       => 'yaatra_mag_footer_style_section',
                'settings'      => 'yaatra_mag_footer_background_heading',
                'label'         => __( 'Background Settings', 'yaatra-mag' ),
            )
        )
    );
    
    /**
     * Color option for footer background
     *
     * Footer Settings > Style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 'yaatra_mag_footer_background_color',
        array(
            'capability'        => 'edit_theme_options',
            'theme_options'     => '',
            'default'           => '#ffffff',
            'sanitize_callback' => 'yaatra_mag_sanitize_alpha_color'
        )
    );

    $wp_customize->add_control( new Yaatra_Mag_Control_Color(
        $wp_customize, 'yaatra_mag_footer_background_color',
            array(
                'priority'          => 40,
                'section'           => 'yaatra_mag_footer_style_section',
                'settings'          => 'yaatra_mag_footer_background_color',
                'label'             => __( 'Footer Background Color', 'yaatra-mag' )
            )
        )
    );

    /**
     * Color option for footer text color
     *
     * Theme Options > Footer > Style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 'yaatra_mag_footer_text_color',
        array(
            'capability'        => 'edit_theme_options',
            'theme_options'     => '',
            'default'           => '#3d3d3d',
            'sanitize_callback' => 'yaatra_mag_sanitize_alpha_color'
        )
    );

    $wp_customize->add_control( new Yaatra_Mag_Control_Color(
        $wp_customize, 'yaatra_mag_footer_text_color',
            array(
                'priority'          => 50,
                'section'           => 'yaatra_mag_footer_style_section',
                'settings'          => 'yaatra_mag_footer_text_color',
                'label'             => __( 'Footer Text Color', 'yaatra-mag' )
            )
        )
    );
}